packageResults: Package the results for sharing with OHDSI researchers

Description Usage Arguments Details

View source: R/helpers.R

Description

Package the results for sharing with OHDSI researchers

Usage

1
packageResults(outputFolder, dbName, minCellCount = 5)

Arguments

outputFolder

Name of folder containing the study analysis results

dbName

A shareable name for the database used in this study

minCellCount

The minimum number of subjects contributing to a count before it can be included in the results.

Details

This function packages the results.


ohdsi-studies/ExistingStrokeRiskExternalValidation documentation built on Aug. 23, 2020, 1:52 p.m.