submitResults: Submit the study results to the study coordinating center

Description Usage Arguments Details Value

View source: R/helpers.R

Description

Submit the study results to the study coordinating center

Usage

1
submitResults(exportFolder, keyLocation, userName)

Arguments

exportFolder

The path to the folder containing the export.zip file.

keyLocation

The keyLocation ask study coordinator to sendfile

userName

The secret userName as provided by the study coordinator

Details

This will upload the file StudyResults.zip to the study coordinating center using Amazon S3. This requires an active internet connection.

Value

TRUE if the upload was successful.


ohdsi-studies/ExistingStrokeRiskExternalValidation documentation built on Aug. 23, 2020, 1:52 p.m.