viewModels: View the coefficients of the models in this study and the...

Description Usage Details Value

View source: R/helpers.R

Description

View the coefficients of the models in this study and the concept ids used to define them

Usage

1

Details

This will print the models and return a data.frame with the models

Value

A data.frame of the models


ohdsi-studies/ExistingStrokeRiskExternalValidation documentation built on Aug. 23, 2020, 1:52 p.m.