Description Usage Arguments Details
Package the results for sharing with OHDSI researchers
1 | packageResults(outputFolder, dbName, minCellCount = 5)
|
outputFolder |
Name of folder containing the study analysis results |
dbName |
A shareable name for the database used in this study |
minCellCount |
The minimum number of subjects contributing to a count before it can be included in the results. |
This function packages the results.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.