Description Usage Arguments Details Value
Submit the study results to the study coordinating center
1 | submitResults(exportFolder, keyLocation, userName)
|
exportFolder |
The path to the folder containing the |
keyLocation |
The keyLocation ask study coordinator to sendfile |
userName |
The secret userName as provided by the study coordinator |
This will upload the file StudyResults.zip to the study coordinating center using Amazon S3.
This requires an active internet connection.
TRUE if the upload was successful.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.